@@ -1,7 +1,7 @@
 #include "spvm_native.h"
 #include "SPVM__IO__Util.h"
 
-int32_t socket_errno (void) {
+int32_t spvm_socket_errno (void) {
 #ifdef _WIN32
   return WSAGetLastError();
 #else
@@ -10,7 +10,7 @@ int32_t socket_errno (void) {
 }
 
 #ifdef _WIN32
-void* socket_strerror_string_win (SPVM_ENV* env, SPVM_VALUE* stack, int32_t error_number, int32_t length) {
+static void* socket_strerror_string_win (SPVM_ENV* env, SPVM_VALUE* stack, int32_t error_number, int32_t length) {
   char* error_message = NULL;
   FormatMessageA(FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS, 
                  NULL, error_number,
@@ -25,7 +25,7 @@ void* socket_strerror_string_win (SPVM_ENV* env, SPVM_VALUE* stack, int32_t erro
 }
 #endif
 
-void* socket_strerror_string (SPVM_ENV* env, SPVM_VALUE* stack, int32_t error_number, int32_t length) {
+static void* socket_strerror_string (SPVM_ENV* env, SPVM_VALUE* stack, int32_t error_number, int32_t length) {
   void*
 #ifdef _WIN32
   obj_strerror_value = socket_strerror_string_win(env, stack, error_number, length);
@@ -35,26 +35,7 @@ void* socket_strerror_string (SPVM_ENV* env, SPVM_VALUE* stack, int32_t error_nu
   return obj_strerror_value;
 }
 
-int32_t SPVM__Sys__Socket__socket_errno(SPVM_ENV* env, SPVM_VALUE* stack) {
-  int32_t ret_socket_errno = socket_errno();
-  
-  stack[0].ival = ret_socket_errno;
-  
-  return 0;
-}
-
-int32_t SPVM__Sys__Socket__socket_strerror(SPVM_ENV* env, SPVM_VALUE* stack) {
-  int32_t error_number = stack[0].ival;
-  int32_t length = stack[1].ival;
-  
-  void* obj_socket_strerror = socket_strerror_string(env, stack, error_number, length);
-  
-  stack[0].oval = obj_socket_strerror;
-  
-  return 0;
-}
-
-const char* socket_strerror(SPVM_ENV* env, SPVM_VALUE* stack, int32_t error_number, int32_t length) {
+const char* spvm_socket_strerror(SPVM_ENV* env, SPVM_VALUE* stack, int32_t error_number, int32_t length) {
   void* obj_socket_strerror = socket_strerror_string(env, stack, error_number, length);
   
   const char* ret_socket_strerror = NULL;
